@@ -1,6 +1,7 @@
 import numpy
 import xarray
 import matplotlib.pyplot as plt
+from osgeo import gdal
 
 class objearth():
     def __init__(self):
@@ -227,3 +228,13 @@ class objearth():
         index_inf = numpy.random.choice(data.size,inf,replace=1)
         data.ravel()[index_inf] = numpy.inf
         return data
+
+    @staticmethod
+    def band_combination(RED,GREEN,BLUE,bright=10):
+        red    = RED/10000   *bright
+        green  = GREEN/10000 *bright
+        blue   = BLUE/10000  *bright
+        return numpy.stack([red,green,blue],axis=2)
+    @staticmethod
+    def bandopen(target):
+        return gdal.Open(target).ReadAsArray()
\ No newline at end of file
